# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/python-proto-http for more details.
"""Generated protocol buffer code."""

from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class AtlasClient:
    def __init__(self, transport):
        self.transport = transport

    def CreateObject(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/CreateObject",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.CreateObjectOutput"),
            **kwargs,
        )

    def DescribeObject(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/DescribeObject",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.DescribeObjectOutput"),
            **kwargs,
        )

    def DownloadObject(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/DownloadObject",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.DownloadObjectOutput"),
            **kwargs,
        )

    def CreateProblem(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/CreateProblem",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.CreateProblemOutput"),
            **kwargs,
        )

    def DescribeProblem(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/DescribeProblem",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.DescribeProblemOutput"),
            **kwargs,
        )

    def UpdateProblem(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/UpdateProblem",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.UpdateProblemOutput"),
            **kwargs,
        )

    def UpdateStatement(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/UpdateStatement",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.UpdateStatementOutput"),
            **kwargs,
        )

    def DeleteStatement(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/DeleteStatement",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.DeleteStatementOutput"),
            **kwargs,
        )

    def UpdateLimits(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/UpdateLimits",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.UpdateLimitsOutput"),
            **kwargs,
        )

    def UpdateVerifier(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/UpdateVerifier",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.UpdateVerifierOutput"),
            **kwargs,
        )

    def UpdateTests(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/UpdateTests",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.UpdateTestsOutput"),
            **kwargs,
        )

    def DeleteProblem(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/DeleteProblem",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.DeleteProblemOutput"),
            **kwargs,
        )

    def ListPermissions(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/ListPermissions",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.ListPermissionsOutput"),
            **kwargs,
        )

    def GrantPermission(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/GrantPermission",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.GrantPermissionOutput"),
            **kwargs,
        )

    def RevokePermission(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/RevokePermission",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.RevokePermissionOutput"),
            **kwargs,
        )




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/atlas.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import annotations_pb2 as eolymp_dot_annotations_dot_annotations__pb2
from eolymp.executor import verifier_pb2 as eolymp_dot_executor_dot_verifier__pb2
from eolymp.atlas import permission_pb2 as eolymp_dot_atlas_dot_permission__pb2
from eolymp.atlas import problem_pb2 as eolymp_dot_atlas_dot_problem__pb2
from eolymp.atlas import statement_pb2 as eolymp_dot_atlas_dot_statement__pb2
from eolymp.atlas import test_pb2 as eolymp_dot_atlas_dot_test__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/atlas/atlas.proto',
  package='eolymp.atlas',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/atlas;atlas',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18\x65olymp/atlas/atlas.proto\x12\x0c\x65olymp.atlas\x1a$eolymp/annotations/annotations.proto\x1a\x1e\x65olymp/executor/verifier.proto\x1a\x1d\x65olymp/atlas/permission.proto\x1a\x1a\x65olymp/atlas/problem.proto\x1a\x1c\x65olymp/atlas/statement.proto\x1a\x17\x65olymp/atlas/test.proto\"!\n\x11\x43reateObjectInput\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"!\n\x12\x43reateObjectOutput\x12\x0b\n\x03key\x18\x01 \x01(\t\"\"\n\x13\x44\x65scribeObjectInput\x12\x0b\n\x03key\x18\x01 \x01(\t\"\x16\n\x14\x44\x65scribeObjectOutput\"\"\n\x13\x44ownloadObjectInput\x12\x0b\n\x03key\x18\x01 \x01(\t\"$\n\x14\x44ownloadObjectOutput\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"<\n\x12\x43reateProblemInput\x12&\n\x07problem\x18\x01 \x01(\x0b\x32\x15.eolymp.atlas.Problem\")\n\x13\x43reateProblemOutput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"(\n\x12\x44\x65leteProblemInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"\x15\n\x13\x44\x65leteProblemOutput\"\xb6\x01\n\x14\x44\x65scribeProblemInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x19\n\x11preferred_locales\x18\n \x03(\t\x12\x15\n\ronly_examples\x18\x0b \x01(\x08\x12\x15\n\rwith_verifier\x18\x14 \x01(\x08\x12\x17\n\x0fwith_statements\x18\x15 \x01(\x08\x12\x14\n\x0cwith_content\x18\x16 \x01(\x08\x12\x12\n\nwith_tests\x18\x17 \x01(\x08\"?\n\x15\x44\x65scribeProblemOutput\x12&\n\x07problem\x18\x01 \x01(\x0b\x32\x15.eolymp.atlas.Problem\"P\n\x12UpdateProblemInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12&\n\x07problem\x18\x02 \x01(\x0b\x32\x15.eolymp.atlas.Problem\"\x15\n\x13UpdateProblemOutput\"f\n\x14UpdateStatementInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x02 \x01(\t\x12*\n\tstatement\x18\x03 \x01(\x0b\x32\x17.eolymp.atlas.Statement\"\x17\n\x15UpdateStatementOutput\":\n\x14\x44\x65leteStatementInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteStatementOutput\"m\n\x11UpdateLimitsInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x13\n\ntime_limit\x18\xc8\x01 \x01(\x05\x12\x15\n\x0cmemory_limit\x18\xc9\x01 \x01(\x05\x12\x18\n\x0f\x66ile_size_limit\x18\xca\x01 \x01(\x05\"\x14\n\x12UpdateLimitsOutput\"V\n\x13UpdateVerifierInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12+\n\x08verifier\x18\x02 \x01(\x0b\x32\x19.eolymp.executor.Verifier\"\x16\n\x14UpdateVerifierOutput\"I\n\x10UpdateTestsInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12!\n\x05tests\x18\x02 \x03(\x0b\x32\x12.eolymp.atlas.Test\"\x13\n\x11UpdateTestsOutput\"*\n\x14ListPermissionsInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"F\n\x15ListPermissionsOutput\x12-\n\x0bpermissions\x18\x01 \x03(\x0b\x32\x18.eolymp.atlas.Permission\"X\n\x14GrantPermissionInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12,\n\npermission\x18\x02 \x01(\x0b\x32\x18.eolymp.atlas.Permission\"\x17\n\x15GrantPermissionOutput\"<\n\x15RevokePermissionInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"\x18\n\x16RevokePermissionOutput2\xed\x14\n\x05\x41tlas\x12\x84\x01\n\x0c\x43reateObject\x12\x1f.eolymp.atlas.CreateObjectInput\x1a .eolymp.atlas.CreateObjectOutput\"1\x82\xd3\xe4\x93\x02+\"&/twirp/eolymp.atlas.Atlas/CreateObject:\x01*\x12\x8c\x01\n\x0e\x44\x65scribeObject\x12!.eolymp.atlas.DescribeObjectInput\x1a\".eolymp.atlas.DescribeObjectOutput\"3\x82\xd3\xe4\x93\x02-\"(/twirp/eolymp.atlas.Atlas/DescribeObject:\x01*\x12\x8c\x01\n\x0e\x44ownloadObject\x12!.eolymp.atlas.DownloadObjectInput\x1a\".eolymp.atlas.DownloadObjectOutput\"3\x82\xd3\xe4\x93\x02-\"(/twirp/eolymp.atlas.Atlas/DownloadObject:\x01*\x12\xa4\x01\n\rCreateProblem\x12 .eolymp.atlas.CreateProblemInput\x1a!.eolymp.atlas.CreateProblemOutput\"N\x82\xd3\xe4\x93\x02H\"\'/twirp/eolymp.atlas.Atlas/CreateProblem:\x01*Z\x1a\"\x0f/atlas/problems:\x07problem\x12\xb0\x01\n\x0f\x44\x65scribeProblem\x12\".eolymp.atlas.DescribeProblemInput\x1a#.eolymp.atlas.DescribeProblemOutput\"T\x82\xd3\xe4\x93\x02N\")/twirp/eolymp.atlas.Atlas/DescribeProblem:\x01*Z\x1e\x12\x1c/atlas/problems/{problem_id}\x12\xb1\x01\n\rUpdateProblem\x12 .eolymp.atlas.UpdateProblemInput\x1a!.eolymp.atlas.UpdateProblemOutput\"[\x82\xd3\xe4\x93\x02U\"\'/twirp/eolymp.atlas.Atlas/UpdateProblem:\x01*Z\'\"\x1c/atlas/problems/{problem_id}:\x07problem\x12\xcf\x01\n\x0fUpdateStatement\x12\".eolymp.atlas.UpdateStatementInput\x1a#.eolymp.atlas.UpdateStatementOutput\"s\x82\xd3\xe4\x93\x02m\")/twirp/eolymp.atlas.Atlas/UpdateStatement:\x01*Z=\"0/atlas/problems/{problem_id}/statements/{locale}:\tstatement\x12\xc4\x01\n\x0f\x44\x65leteStatement\x12\".eolymp.atlas.DeleteStatementInput\x1a#.eolymp.atlas.DeleteStatementOutput\"h\x82\xd3\xe4\x93\x02\x62\")/twirp/eolymp.atlas.Atlas/DeleteStatement:\x01*Z2*0/atlas/problems/{problem_id}/statements/{locale}\x12\xae\x01\n\x0cUpdateLimits\x12\x1f.eolymp.atlas.UpdateLimitsInput\x1a .eolymp.atlas.UpdateLimitsOutput\"[\x82\xd3\xe4\x93\x02U\"&/twirp/eolymp.atlas.Atlas/UpdateLimits:\x01*Z(\"#/atlas/problems/{problem_id}/limits:\x01*\x12\xb8\x01\n\x0eUpdateVerifier\x12!.eolymp.atlas.UpdateVerifierInput\x1a\".eolymp.atlas.UpdateVerifierOutput\"_\x82\xd3\xe4\x93\x02Y\"(/twirp/eolymp.atlas.Atlas/UpdateVerifier:\x01*Z*\"%/atlas/problems/{problem_id}/verifier:\x01*\x12\xa9\x01\n\x0bUpdateTests\x12\x1e.eolymp.atlas.UpdateTestsInput\x1a\x1f.eolymp.atlas.UpdateTestsOutput\"Y\x82\xd3\xe4\x93\x02S\"%/twirp/eolymp.atlas.Atlas/UpdateTests:\x01*Z\'\"\"/atlas/problems/{problem_id}/tests:\x01*\x12\xa8\x01\n\rDeleteProblem\x12 .eolymp.atlas.DeleteProblemInput\x1a!.eolymp.atlas.DeleteProblemOutput\"R\x82\xd3\xe4\x93\x02L\"\'/twirp/eolymp.atlas.Atlas/DeleteProblem:\x01*Z\x1e*\x1c/atlas/problems/{problem_id}\x12\xbc\x01\n\x0fListPermissions\x12\".eolymp.atlas.ListPermissionsInput\x1a#.eolymp.atlas.ListPermissionsOutput\"`\x82\xd3\xe4\x93\x02Z\")/twirp/eolymp.atlas.Atlas/ListPermissions:\x01*Z*\x12(/atlas/problems/{problem_id}/permissions\x12\xc8\x01\n\x0fGrantPermission\x12\".eolymp.atlas.GrantPermissionInput\x1a#.eolymp.atlas.GrantPermissionOutput\"l\x82\xd3\xe4\x93\x02\x66\")/twirp/eolymp.atlas.Atlas/GrantPermission:\x01*Z6\"(/atlas/problems/{problem_id}/permissions:\npermission\x12\xca\x01\n\x10RevokePermission\x12#.eolymp.atlas.RevokePermissionInput\x1a$.eolymp.atlas.RevokePermissionOutput\"k\x82\xd3\xe4\x93\x02\x65\"*/twirp/eolymp.atlas.Atlas/RevokePermission:\x01*Z4*2/atlas/problems/{problem_id}/permissions/{user_id}B3Z1github.com/eolymp/contracts/go/eolymp/atlas;atlasb\x06proto3'
  ,
  dependencies=[eolymp_dot_annotations_dot_annotations__pb2.DESCRIPTOR,eolymp_dot_executor_dot_verifier__pb2.DESCRIPTOR,eolymp_dot_atlas_dot_permission__pb2.DESCRIPTOR,eolymp_dot_atlas_dot_problem__pb2.DESCRIPTOR,eolymp_dot_atlas_dot_statement__pb2.DESCRIPTOR,eolymp_dot_atlas_dot_test__pb2.DESCRIPTOR,])




_CREATEOBJECTINPUT = _descriptor.Descriptor(
  name='CreateObjectInput',
  full_name='eolymp.atlas.CreateObjectInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='eolymp.atlas.CreateObjectInput.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=226,
  serialized_end=259,
)


_CREATEOBJECTOUTPUT = _descriptor.Descriptor(
  name='CreateObjectOutput',
  full_name='eolymp.atlas.CreateObjectOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='eolymp.atlas.CreateObjectOutput.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=261,
  serialized_end=294,
)


_DESCRIBEOBJECTINPUT = _descriptor.Descriptor(
  name='DescribeObjectInput',
  full_name='eolymp.atlas.DescribeObjectInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='eolymp.atlas.DescribeObjectInput.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=296,
  serialized_end=330,
)


_DESCRIBEOBJECTOUTPUT = _descriptor.Descriptor(
  name='DescribeObjectOutput',
  full_name='eolymp.atlas.DescribeObjectOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=332,
  serialized_end=354,
)


_DOWNLOADOBJECTINPUT = _descriptor.Descriptor(
  name='DownloadObjectInput',
  full_name='eolymp.atlas.DownloadObjectInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='eolymp.atlas.DownloadObjectInput.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=356,
  serialized_end=390,
)


_DOWNLOADOBJECTOUTPUT = _descriptor.Descriptor(
  name='DownloadObjectOutput',
  full_name='eolymp.atlas.DownloadObjectOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='eolymp.atlas.DownloadObjectOutput.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=392,
  serialized_end=428,
)


_CREATEPROBLEMINPUT = _descriptor.Descriptor(
  name='CreateProblemInput',
  full_name='eolymp.atlas.CreateProblemInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem', full_name='eolymp.atlas.CreateProblemInput.problem', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=430,
  serialized_end=490,
)


_CREATEPROBLEMOUTPUT = _descriptor.Descriptor(
  name='CreateProblemOutput',
  full_name='eolymp.atlas.CreateProblemOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.CreateProblemOutput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=492,
  serialized_end=533,
)


_DELETEPROBLEMINPUT = _descriptor.Descriptor(
  name='DeleteProblemInput',
  full_name='eolymp.atlas.DeleteProblemInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.DeleteProblemInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=535,
  serialized_end=575,
)


_DELETEPROBLEMOUTPUT = _descriptor.Descriptor(
  name='DeleteProblemOutput',
  full_name='eolymp.atlas.DeleteProblemOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=577,
  serialized_end=598,
)


_DESCRIBEPROBLEMINPUT = _descriptor.Descriptor(
  name='DescribeProblemInput',
  full_name='eolymp.atlas.DescribeProblemInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.DescribeProblemInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preferred_locales', full_name='eolymp.atlas.DescribeProblemInput.preferred_locales', index=1,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='only_examples', full_name='eolymp.atlas.DescribeProblemInput.only_examples', index=2,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_verifier', full_name='eolymp.atlas.DescribeProblemInput.with_verifier', index=3,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_statements', full_name='eolymp.atlas.DescribeProblemInput.with_statements', index=4,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_content', full_name='eolymp.atlas.DescribeProblemInput.with_content', index=5,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_tests', full_name='eolymp.atlas.DescribeProblemInput.with_tests', index=6,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=601,
  serialized_end=783,
)


_DESCRIBEPROBLEMOUTPUT = _descriptor.Descriptor(
  name='DescribeProblemOutput',
  full_name='eolymp.atlas.DescribeProblemOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem', full_name='eolymp.atlas.DescribeProblemOutput.problem', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=785,
  serialized_end=848,
)


_UPDATEPROBLEMINPUT = _descriptor.Descriptor(
  name='UpdateProblemInput',
  full_name='eolymp.atlas.UpdateProblemInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.UpdateProblemInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='problem', full_name='eolymp.atlas.UpdateProblemInput.problem', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=850,
  serialized_end=930,
)


_UPDATEPROBLEMOUTPUT = _descriptor.Descriptor(
  name='UpdateProblemOutput',
  full_name='eolymp.atlas.UpdateProblemOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=932,
  serialized_end=953,
)


_UPDATESTATEMENTINPUT = _descriptor.Descriptor(
  name='UpdateStatementInput',
  full_name='eolymp.atlas.UpdateStatementInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.UpdateStatementInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locale', full_name='eolymp.atlas.UpdateStatementInput.locale', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statement', full_name='eolymp.atlas.UpdateStatementInput.statement', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=955,
  serialized_end=1057,
)


_UPDATESTATEMENTOUTPUT = _descriptor.Descriptor(
  name='UpdateStatementOutput',
  full_name='eolymp.atlas.UpdateStatementOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1059,
  serialized_end=1082,
)


_DELETESTATEMENTINPUT = _descriptor.Descriptor(
  name='DeleteStatementInput',
  full_name='eolymp.atlas.DeleteStatementInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.DeleteStatementInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locale', full_name='eolymp.atlas.DeleteStatementInput.locale', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1084,
  serialized_end=1142,
)


_DELETESTATEMENTOUTPUT = _descriptor.Descriptor(
  name='DeleteStatementOutput',
  full_name='eolymp.atlas.DeleteStatementOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1144,
  serialized_end=1167,
)


_UPDATELIMITSINPUT = _descriptor.Descriptor(
  name='UpdateLimitsInput',
  full_name='eolymp.atlas.UpdateLimitsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.UpdateLimitsInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_limit', full_name='eolymp.atlas.UpdateLimitsInput.time_limit', index=1,
      number=200, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='memory_limit', full_name='eolymp.atlas.UpdateLimitsInput.memory_limit', index=2,
      number=201, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_size_limit', full_name='eolymp.atlas.UpdateLimitsInput.file_size_limit', index=3,
      number=202, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1169,
  serialized_end=1278,
)


_UPDATELIMITSOUTPUT = _descriptor.Descriptor(
  name='UpdateLimitsOutput',
  full_name='eolymp.atlas.UpdateLimitsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1280,
  serialized_end=1300,
)


_UPDATEVERIFIERINPUT = _descriptor.Descriptor(
  name='UpdateVerifierInput',
  full_name='eolymp.atlas.UpdateVerifierInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.UpdateVerifierInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='verifier', full_name='eolymp.atlas.UpdateVerifierInput.verifier', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1302,
  serialized_end=1388,
)


_UPDATEVERIFIEROUTPUT = _descriptor.Descriptor(
  name='UpdateVerifierOutput',
  full_name='eolymp.atlas.UpdateVerifierOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1390,
  serialized_end=1412,
)


_UPDATETESTSINPUT = _descriptor.Descriptor(
  name='UpdateTestsInput',
  full_name='eolymp.atlas.UpdateTestsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.UpdateTestsInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tests', full_name='eolymp.atlas.UpdateTestsInput.tests', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1414,
  serialized_end=1487,
)


_UPDATETESTSOUTPUT = _descriptor.Descriptor(
  name='UpdateTestsOutput',
  full_name='eolymp.atlas.UpdateTestsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1489,
  serialized_end=1508,
)


_LISTPERMISSIONSINPUT = _descriptor.Descriptor(
  name='ListPermissionsInput',
  full_name='eolymp.atlas.ListPermissionsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.ListPermissionsInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1510,
  serialized_end=1552,
)


_LISTPERMISSIONSOUTPUT = _descriptor.Descriptor(
  name='ListPermissionsOutput',
  full_name='eolymp.atlas.ListPermissionsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='permissions', full_name='eolymp.atlas.ListPermissionsOutput.permissions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1554,
  serialized_end=1624,
)


_GRANTPERMISSIONINPUT = _descriptor.Descriptor(
  name='GrantPermissionInput',
  full_name='eolymp.atlas.GrantPermissionInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.GrantPermissionInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permission', full_name='eolymp.atlas.GrantPermissionInput.permission', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1626,
  serialized_end=1714,
)


_GRANTPERMISSIONOUTPUT = _descriptor.Descriptor(
  name='GrantPermissionOutput',
  full_name='eolymp.atlas.GrantPermissionOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1716,
  serialized_end=1739,
)


_REVOKEPERMISSIONINPUT = _descriptor.Descriptor(
  name='RevokePermissionInput',
  full_name='eolymp.atlas.RevokePermissionInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.RevokePermissionInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.atlas.RevokePermissionInput.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1741,
  serialized_end=1801,
)


_REVOKEPERMISSIONOUTPUT = _descriptor.Descriptor(
  name='RevokePermissionOutput',
  full_name='eolymp.atlas.RevokePermissionOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1803,
  serialized_end=1827,
)

_CREATEPROBLEMINPUT.fields_by_name['problem'].message_type = eolymp_dot_atlas_dot_problem__pb2._PROBLEM
_DESCRIBEPROBLEMOUTPUT.fields_by_name['problem'].message_type = eolymp_dot_atlas_dot_problem__pb2._PROBLEM
_UPDATEPROBLEMINPUT.fields_by_name['problem'].message_type = eolymp_dot_atlas_dot_problem__pb2._PROBLEM
_UPDATESTATEMENTINPUT.fields_by_name['statement'].message_type = eolymp_dot_atlas_dot_statement__pb2._STATEMENT
_UPDATEVERIFIERINPUT.fields_by_name['verifier'].message_type = eolymp_dot_executor_dot_verifier__pb2._VERIFIER
_UPDATETESTSINPUT.fields_by_name['tests'].message_type = eolymp_dot_atlas_dot_test__pb2._TEST
_LISTPERMISSIONSOUTPUT.fields_by_name['permissions'].message_type = eolymp_dot_atlas_dot_permission__pb2._PERMISSION
_GRANTPERMISSIONINPUT.fields_by_name['permission'].message_type = eolymp_dot_atlas_dot_permission__pb2._PERMISSION
DESCRIPTOR.message_types_by_name['CreateObjectInput'] = _CREATEOBJECTINPUT
DESCRIPTOR.message_types_by_name['CreateObjectOutput'] = _CREATEOBJECTOUTPUT
DESCRIPTOR.message_types_by_name['DescribeObjectInput'] = _DESCRIBEOBJECTINPUT
DESCRIPTOR.message_types_by_name['DescribeObjectOutput'] = _DESCRIBEOBJECTOUTPUT
DESCRIPTOR.message_types_by_name['DownloadObjectInput'] = _DOWNLOADOBJECTINPUT
DESCRIPTOR.message_types_by_name['DownloadObjectOutput'] = _DOWNLOADOBJECTOUTPUT
DESCRIPTOR.message_types_by_name['CreateProblemInput'] = _CREATEPROBLEMINPUT
DESCRIPTOR.message_types_by_name['CreateProblemOutput'] = _CREATEPROBLEMOUTPUT
DESCRIPTOR.message_types_by_name['DeleteProblemInput'] = _DELETEPROBLEMINPUT
DESCRIPTOR.message_types_by_name['DeleteProblemOutput'] = _DELETEPROBLEMOUTPUT
DESCRIPTOR.message_types_by_name['DescribeProblemInput'] = _DESCRIBEPROBLEMINPUT
DESCRIPTOR.message_types_by_name['DescribeProblemOutput'] = _DESCRIBEPROBLEMOUTPUT
DESCRIPTOR.message_types_by_name['UpdateProblemInput'] = _UPDATEPROBLEMINPUT
DESCRIPTOR.message_types_by_name['UpdateProblemOutput'] = _UPDATEPROBLEMOUTPUT
DESCRIPTOR.message_types_by_name['UpdateStatementInput'] = _UPDATESTATEMENTINPUT
DESCRIPTOR.message_types_by_name['UpdateStatementOutput'] = _UPDATESTATEMENTOUTPUT
DESCRIPTOR.message_types_by_name['DeleteStatementInput'] = _DELETESTATEMENTINPUT
DESCRIPTOR.message_types_by_name['DeleteStatementOutput'] = _DELETESTATEMENTOUTPUT
DESCRIPTOR.message_types_by_name['UpdateLimitsInput'] = _UPDATELIMITSINPUT
DESCRIPTOR.message_types_by_name['UpdateLimitsOutput'] = _UPDATELIMITSOUTPUT
DESCRIPTOR.message_types_by_name['UpdateVerifierInput'] = _UPDATEVERIFIERINPUT
DESCRIPTOR.message_types_by_name['UpdateVerifierOutput'] = _UPDATEVERIFIEROUTPUT
DESCRIPTOR.message_types_by_name['UpdateTestsInput'] = _UPDATETESTSINPUT
DESCRIPTOR.message_types_by_name['UpdateTestsOutput'] = _UPDATETESTSOUTPUT
DESCRIPTOR.message_types_by_name['ListPermissionsInput'] = _LISTPERMISSIONSINPUT
DESCRIPTOR.message_types_by_name['ListPermissionsOutput'] = _LISTPERMISSIONSOUTPUT
DESCRIPTOR.message_types_by_name['GrantPermissionInput'] = _GRANTPERMISSIONINPUT
DESCRIPTOR.message_types_by_name['GrantPermissionOutput'] = _GRANTPERMISSIONOUTPUT
DESCRIPTOR.message_types_by_name['RevokePermissionInput'] = _REVOKEPERMISSIONINPUT
DESCRIPTOR.message_types_by_name['RevokePermissionOutput'] = _REVOKEPERMISSIONOUTPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateObjectInput = _reflection.GeneratedProtocolMessageType('CreateObjectInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATEOBJECTINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.CreateObjectInput)
  })
_sym_db.RegisterMessage(CreateObjectInput)

CreateObjectOutput = _reflection.GeneratedProtocolMessageType('CreateObjectOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATEOBJECTOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.CreateObjectOutput)
  })
_sym_db.RegisterMessage(CreateObjectOutput)

DescribeObjectInput = _reflection.GeneratedProtocolMessageType('DescribeObjectInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEOBJECTINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DescribeObjectInput)
  })
_sym_db.RegisterMessage(DescribeObjectInput)

DescribeObjectOutput = _reflection.GeneratedProtocolMessageType('DescribeObjectOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEOBJECTOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DescribeObjectOutput)
  })
_sym_db.RegisterMessage(DescribeObjectOutput)

DownloadObjectInput = _reflection.GeneratedProtocolMessageType('DownloadObjectInput', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADOBJECTINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DownloadObjectInput)
  })
_sym_db.RegisterMessage(DownloadObjectInput)

DownloadObjectOutput = _reflection.GeneratedProtocolMessageType('DownloadObjectOutput', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADOBJECTOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DownloadObjectOutput)
  })
_sym_db.RegisterMessage(DownloadObjectOutput)

CreateProblemInput = _reflection.GeneratedProtocolMessageType('CreateProblemInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROBLEMINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.CreateProblemInput)
  })
_sym_db.RegisterMessage(CreateProblemInput)

CreateProblemOutput = _reflection.GeneratedProtocolMessageType('CreateProblemOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROBLEMOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.CreateProblemOutput)
  })
_sym_db.RegisterMessage(CreateProblemOutput)

DeleteProblemInput = _reflection.GeneratedProtocolMessageType('DeleteProblemInput', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPROBLEMINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DeleteProblemInput)
  })
_sym_db.RegisterMessage(DeleteProblemInput)

DeleteProblemOutput = _reflection.GeneratedProtocolMessageType('DeleteProblemOutput', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPROBLEMOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DeleteProblemOutput)
  })
_sym_db.RegisterMessage(DeleteProblemOutput)

DescribeProblemInput = _reflection.GeneratedProtocolMessageType('DescribeProblemInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEPROBLEMINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DescribeProblemInput)
  })
_sym_db.RegisterMessage(DescribeProblemInput)

DescribeProblemOutput = _reflection.GeneratedProtocolMessageType('DescribeProblemOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEPROBLEMOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DescribeProblemOutput)
  })
_sym_db.RegisterMessage(DescribeProblemOutput)

UpdateProblemInput = _reflection.GeneratedProtocolMessageType('UpdateProblemInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROBLEMINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.UpdateProblemInput)
  })
_sym_db.RegisterMessage(UpdateProblemInput)

UpdateProblemOutput = _reflection.GeneratedProtocolMessageType('UpdateProblemOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROBLEMOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.UpdateProblemOutput)
  })
_sym_db.RegisterMessage(UpdateProblemOutput)

UpdateStatementInput = _reflection.GeneratedProtocolMessageType('UpdateStatementInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESTATEMENTINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.UpdateStatementInput)
  })
_sym_db.RegisterMessage(UpdateStatementInput)

UpdateStatementOutput = _reflection.GeneratedProtocolMessageType('UpdateStatementOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESTATEMENTOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.UpdateStatementOutput)
  })
_sym_db.RegisterMessage(UpdateStatementOutput)

DeleteStatementInput = _reflection.GeneratedProtocolMessageType('DeleteStatementInput', (_message.Message,), {
  'DESCRIPTOR' : _DELETESTATEMENTINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DeleteStatementInput)
  })
_sym_db.RegisterMessage(DeleteStatementInput)

DeleteStatementOutput = _reflection.GeneratedProtocolMessageType('DeleteStatementOutput', (_message.Message,), {
  'DESCRIPTOR' : _DELETESTATEMENTOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DeleteStatementOutput)
  })
_sym_db.RegisterMessage(DeleteStatementOutput)

UpdateLimitsInput = _reflection.GeneratedProtocolMessageType('UpdateLimitsInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELIMITSINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.UpdateLimitsInput)
  })
_sym_db.RegisterMessage(UpdateLimitsInput)

UpdateLimitsOutput = _reflection.GeneratedProtocolMessageType('UpdateLimitsOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELIMITSOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.UpdateLimitsOutput)
  })
_sym_db.RegisterMessage(UpdateLimitsOutput)

UpdateVerifierInput = _reflection.GeneratedProtocolMessageType('UpdateVerifierInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVERIFIERINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.UpdateVerifierInput)
  })
_sym_db.RegisterMessage(UpdateVerifierInput)

UpdateVerifierOutput = _reflection.GeneratedProtocolMessageType('UpdateVerifierOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVERIFIEROUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.UpdateVerifierOutput)
  })
_sym_db.RegisterMessage(UpdateVerifierOutput)

UpdateTestsInput = _reflection.GeneratedProtocolMessageType('UpdateTestsInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETESTSINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.UpdateTestsInput)
  })
_sym_db.RegisterMessage(UpdateTestsInput)

UpdateTestsOutput = _reflection.GeneratedProtocolMessageType('UpdateTestsOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETESTSOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.UpdateTestsOutput)
  })
_sym_db.RegisterMessage(UpdateTestsOutput)

ListPermissionsInput = _reflection.GeneratedProtocolMessageType('ListPermissionsInput', (_message.Message,), {
  'DESCRIPTOR' : _LISTPERMISSIONSINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.ListPermissionsInput)
  })
_sym_db.RegisterMessage(ListPermissionsInput)

ListPermissionsOutput = _reflection.GeneratedProtocolMessageType('ListPermissionsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTPERMISSIONSOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.ListPermissionsOutput)
  })
_sym_db.RegisterMessage(ListPermissionsOutput)

GrantPermissionInput = _reflection.GeneratedProtocolMessageType('GrantPermissionInput', (_message.Message,), {
  'DESCRIPTOR' : _GRANTPERMISSIONINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.GrantPermissionInput)
  })
_sym_db.RegisterMessage(GrantPermissionInput)

GrantPermissionOutput = _reflection.GeneratedProtocolMessageType('GrantPermissionOutput', (_message.Message,), {
  'DESCRIPTOR' : _GRANTPERMISSIONOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.GrantPermissionOutput)
  })
_sym_db.RegisterMessage(GrantPermissionOutput)

RevokePermissionInput = _reflection.GeneratedProtocolMessageType('RevokePermissionInput', (_message.Message,), {
  'DESCRIPTOR' : _REVOKEPERMISSIONINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.RevokePermissionInput)
  })
_sym_db.RegisterMessage(RevokePermissionInput)

RevokePermissionOutput = _reflection.GeneratedProtocolMessageType('RevokePermissionOutput', (_message.Message,), {
  'DESCRIPTOR' : _REVOKEPERMISSIONOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.RevokePermissionOutput)
  })
_sym_db.RegisterMessage(RevokePermissionOutput)


DESCRIPTOR._options = None

_ATLAS = _descriptor.ServiceDescriptor(
  name='Atlas',
  full_name='eolymp.atlas.Atlas',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1830,
  serialized_end=4499,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateObject',
    full_name='eolymp.atlas.Atlas.CreateObject',
    index=0,
    containing_service=None,
    input_type=_CREATEOBJECTINPUT,
    output_type=_CREATEOBJECTOUTPUT,
    serialized_options=b'\202\323\344\223\002+\"&/twirp/eolymp.atlas.Atlas/CreateObject:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeObject',
    full_name='eolymp.atlas.Atlas.DescribeObject',
    index=1,
    containing_service=None,
    input_type=_DESCRIBEOBJECTINPUT,
    output_type=_DESCRIBEOBJECTOUTPUT,
    serialized_options=b'\202\323\344\223\002-\"(/twirp/eolymp.atlas.Atlas/DescribeObject:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DownloadObject',
    full_name='eolymp.atlas.Atlas.DownloadObject',
    index=2,
    containing_service=None,
    input_type=_DOWNLOADOBJECTINPUT,
    output_type=_DOWNLOADOBJECTOUTPUT,
    serialized_options=b'\202\323\344\223\002-\"(/twirp/eolymp.atlas.Atlas/DownloadObject:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateProblem',
    full_name='eolymp.atlas.Atlas.CreateProblem',
    index=3,
    containing_service=None,
    input_type=_CREATEPROBLEMINPUT,
    output_type=_CREATEPROBLEMOUTPUT,
    serialized_options=b'\202\323\344\223\002H\"\'/twirp/eolymp.atlas.Atlas/CreateProblem:\001*Z\032\"\017/atlas/problems:\007problem',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeProblem',
    full_name='eolymp.atlas.Atlas.DescribeProblem',
    index=4,
    containing_service=None,
    input_type=_DESCRIBEPROBLEMINPUT,
    output_type=_DESCRIBEPROBLEMOUTPUT,
    serialized_options=b'\202\323\344\223\002N\")/twirp/eolymp.atlas.Atlas/DescribeProblem:\001*Z\036\022\034/atlas/problems/{problem_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateProblem',
    full_name='eolymp.atlas.Atlas.UpdateProblem',
    index=5,
    containing_service=None,
    input_type=_UPDATEPROBLEMINPUT,
    output_type=_UPDATEPROBLEMOUTPUT,
    serialized_options=b'\202\323\344\223\002U\"\'/twirp/eolymp.atlas.Atlas/UpdateProblem:\001*Z\'\"\034/atlas/problems/{problem_id}:\007problem',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateStatement',
    full_name='eolymp.atlas.Atlas.UpdateStatement',
    index=6,
    containing_service=None,
    input_type=_UPDATESTATEMENTINPUT,
    output_type=_UPDATESTATEMENTOUTPUT,
    serialized_options=b'\202\323\344\223\002m\")/twirp/eolymp.atlas.Atlas/UpdateStatement:\001*Z=\"0/atlas/problems/{problem_id}/statements/{locale}:\tstatement',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteStatement',
    full_name='eolymp.atlas.Atlas.DeleteStatement',
    index=7,
    containing_service=None,
    input_type=_DELETESTATEMENTINPUT,
    output_type=_DELETESTATEMENTOUTPUT,
    serialized_options=b'\202\323\344\223\002b\")/twirp/eolymp.atlas.Atlas/DeleteStatement:\001*Z2*0/atlas/problems/{problem_id}/statements/{locale}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateLimits',
    full_name='eolymp.atlas.Atlas.UpdateLimits',
    index=8,
    containing_service=None,
    input_type=_UPDATELIMITSINPUT,
    output_type=_UPDATELIMITSOUTPUT,
    serialized_options=b'\202\323\344\223\002U\"&/twirp/eolymp.atlas.Atlas/UpdateLimits:\001*Z(\"#/atlas/problems/{problem_id}/limits:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateVerifier',
    full_name='eolymp.atlas.Atlas.UpdateVerifier',
    index=9,
    containing_service=None,
    input_type=_UPDATEVERIFIERINPUT,
    output_type=_UPDATEVERIFIEROUTPUT,
    serialized_options=b'\202\323\344\223\002Y\"(/twirp/eolymp.atlas.Atlas/UpdateVerifier:\001*Z*\"%/atlas/problems/{problem_id}/verifier:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateTests',
    full_name='eolymp.atlas.Atlas.UpdateTests',
    index=10,
    containing_service=None,
    input_type=_UPDATETESTSINPUT,
    output_type=_UPDATETESTSOUTPUT,
    serialized_options=b'\202\323\344\223\002S\"%/twirp/eolymp.atlas.Atlas/UpdateTests:\001*Z\'\"\"/atlas/problems/{problem_id}/tests:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteProblem',
    full_name='eolymp.atlas.Atlas.DeleteProblem',
    index=11,
    containing_service=None,
    input_type=_DELETEPROBLEMINPUT,
    output_type=_DELETEPROBLEMOUTPUT,
    serialized_options=b'\202\323\344\223\002L\"\'/twirp/eolymp.atlas.Atlas/DeleteProblem:\001*Z\036*\034/atlas/problems/{problem_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListPermissions',
    full_name='eolymp.atlas.Atlas.ListPermissions',
    index=12,
    containing_service=None,
    input_type=_LISTPERMISSIONSINPUT,
    output_type=_LISTPERMISSIONSOUTPUT,
    serialized_options=b'\202\323\344\223\002Z\")/twirp/eolymp.atlas.Atlas/ListPermissions:\001*Z*\022(/atlas/problems/{problem_id}/permissions',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GrantPermission',
    full_name='eolymp.atlas.Atlas.GrantPermission',
    index=13,
    containing_service=None,
    input_type=_GRANTPERMISSIONINPUT,
    output_type=_GRANTPERMISSIONOUTPUT,
    serialized_options=b'\202\323\344\223\002f\")/twirp/eolymp.atlas.Atlas/GrantPermission:\001*Z6\"(/atlas/problems/{problem_id}/permissions:\npermission',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RevokePermission',
    full_name='eolymp.atlas.Atlas.RevokePermission',
    index=14,
    containing_service=None,
    input_type=_REVOKEPERMISSIONINPUT,
    output_type=_REVOKEPERMISSIONOUTPUT,
    serialized_options=b'\202\323\344\223\002e\"*/twirp/eolymp.atlas.Atlas/RevokePermission:\001*Z4*2/atlas/problems/{problem_id}/permissions/{user_id}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ATLAS)

DESCRIPTOR.services_by_name['Atlas'] = _ATLAS

# @@protoc_insertion_point(module_scope)
